import { useUserStore } from '@/stores/modules/user';
import Taro from '@tarojs/taro';
import { object2query } from '@life-payment/utils';
import * as userServices from '@life-payment/services/api/User';
import { useQuery } from '@tanstack/vue-query';
import { MaybeRef } from 'vue';
import { useRefeshDidShow } from './infiniteLoading';
import { LoginFormTabs } from '@/subpackages/login/constants';
import { useLoginedJump } from './login';
import { useLifeRechargeContext, APIgetLifePayWxIndentityParams } from '@life-payment/core-vue';
import { isInWeChat } from '@/utils/env';

export function useUser() {
  const userStore = useUserStore();

  const {
    userDetail,
    userInfo,
    locationCity,
    virtualUserId,
    virtualPhoneNumber,
    wxCode,
    wxOpenId,
  } = storeToRefs(userStore);

  function updateUserInfo() {
    return userStore.getCurrentUserInfo();
  }

  return {
    user: userInfo,
    userDetail: userDetail,
    updateUserInfo,
    locationCity,
    virtualUserId,
    virtualPhoneNumber,
    wxCode,
    wxOpenId,
  };
}

export function useIsLogin() {
  const { virtualUserId } = useUser();
  // return computed(() => !!user.value);
  return computed(() => !!virtualUserId.value);
}

type UseAuthOptions = {
  needAuth?: boolean;
};

export function useAuth(options: UseAuthOptions = {}) {
  const { needAuth = true } = options;
  const userStore = useUserStore();

  const isLogin = useIsLogin();

  const isAuth = computed(() => !needAuth || isLogin.value);

  const router = Taro.useRouter();
  useInitWeixinJSBridge();

  Taro.useReady(async () => {
    if (isLogin.value && userStore.firstGetUserDetail) {
      // userStore.getCurrentUserInfo();
    }
    if (needAuth && !isLogin.value) {
      Taro.navigateTo({
        url: `${RouterPath.loginByForm}?redirect=${router.path}&${object2query(router.params)}`,
      });
    }
  });

  return { isAuth };
}

export function useInitWeixinJSBridge() {
  const { wxCode } = useUser();

  const userStore = useUserStore();
  const router = Taro.useRouter();

  const code = router.params.code ?? '';

  const { blLifeRecharge } = useLifeRechargeContext();

  Taro.useReady(async () => {
    try {
      //@ts-ignore
      if (!code && isInWeChat && !wxCode.value && location?.replace) {
        location.replace(
          `https://open.weixin.qq.com/connect/oauth2/authorize?appid=wxf940ff1d35a98493&redirect_uri=${location.href}&response_type=code&scope=snsapi_base#wechat_redirect`
        );
      }
      if (!!code && !wxCode.value) {
        userStore.setWxCode(router.params.code ?? '');
        let res = await getLifePayWxIndentity();
        userStore.setWxOpenId(res.openId);
      }
    } catch (error) {}
  });

  async function getLifePayWxIndentity() {
    try {
      let params: APIgetLifePayWxIndentityParams = {
        code: code,
      };
      let res = await blLifeRecharge.services.getLifePayWxIndentity(params, {
        showLoading: false,
      });
      return res;
    } catch (error) {}
  }
}

export function useGoLogin() {
  const router = Taro.useRouter();
  const { redirectParams } = useLoginedJump();
  function goLoginFn() {
    // Taro.navigateTo({
    //   url: `${RouterPath.authorization}?redirect=${router.path}&${object2query(router.params)}`,
    // });

    Taro.navigateTo({
      url: `${RouterPath.loginByForm}?redirect=${redirectParams.value}&tab=${LoginFormTabs.VerificationCodeLogin}`,
    });
  }

  return {
    goLoginFn,
  };
}
